#include <xc.h>
#include <stdio.h>

#include "Tick.h"
#include "Delay.h"
#include "UART.h"
#include "EEPROM.h"

// Fusibles de configuracin MCLR (reset) Activo, Proteccin de lectura desactivada
// Bronw-out reset desactivado, perro guardian desactivado, Power-up timer desactivado
// Oscilador a cristal de cuarzo activo

// CONFIG1
#pragma config FOSC = INTOSCIO	// Oscillator Selection bits (XT oscillator)
#pragma config WDTE = OFF       // Watchdog Timer Enable bit (WDT disabled)
#pragma config PWRTE = OFF      // Power-up Timer Enable bit (PWRT disabled)
#pragma config MCLRE = ON       // RA5/MCLR/VPP Pin Function Select bit (RA5/MCLR/VPP pin function is MCLR)
#pragma config BOREN = OFF      // Brown-out Reset Enable bit (BOR disabled)
#pragma config LVP = OFF        // Low-Voltage Programming Enable bit (RB3 is digital I/O, HV on MCLR must be used for programming)
#pragma config CPD = OFF        // Data EE Memory Code Protection bit (Code protection off)
#pragma config WRT = OFF        // Flash Program Memory Write Enable bits (Write protection off)
#pragma config CCPMX = RB0      // CCP1 Pin Selection bit (CCP1 function on RB0)
#pragma config CP = OFF         // Flash Program Memory Code Protection bit (Code protection off)

// CONFIG2
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable bit (Fail-Safe Clock Monitor disabled)
#pragma config IESO = OFF       // Internal External Switchover bit (Internal External Switchover mode disabled)

xUARTHandle xSerial;
unsigned char ucCount;
unsigned long ulLastTick = 0;

/**
 Implementacin de la funcionalidad principal del programa
*/
void main()
{
	//OSCCON = 0x6C;		// Para usar el oscilador interno PIC16F88 4 Mhz
	OSCCON = 0x7C;			// Para usar el oscilador interno PIC16F88 8 Mhz
	ANSEL = 0x00;			// Configuracion de canales analogicos en PIC16F88

	TRISA = 0xEF;		// Puerto A como entradas menos RA4 (led indicador)
	TRISB = 0xFF;		// Puerto B todo como entradas
	PORTA = 0;
	PORTB = 0;

	vTickInitialize();	// Iniciar el contador / temporizador del sistema
	xSerial = xUARTInitialize( E_UART_1 );		// Iniciamos nuestro puerto serie

	// Abrir el puerto serie
	xUARTOpen( xSerial );
	vDelayMilis(10);
	// Mostrar mensajes iniciales, para saber que la comunicacin serial funciona
	vUARTPuts( xSerial, "Entrenadora con PIC16F628\r\n" );
	vUARTPuts( xSerial, "Programa de prueba EEPROM Interna\r\n" );

	// Verificamos si ya hay datos en EEPROM que hayamos escrito
	if( xEEPROMRead( 0x00 ) == 0xAA )
	{

		vUARTPuts( xSerial,"Encontrados datos en la EEPROM!!\r\n");
		for( ucCount = 1; ucCount <= 9; ucCount++)
		{
			// Imprimimos los nmeros que grabamos previamente, uno en cada linea
			vUARTPuts( xSerial, "Leido: ");
			vUARTWrite( xSerial, ( xEEPROMRead( ucCount ) | 0x30 ) );
			vUARTPuts( xSerial, "\r\n");
		}
	}

	// Ciclo principal de nuestra aplicacin
	for(;;)
	{
		// Para el parpadeo del led y verificar si el boton en RA0 esta oprimido
		if( xTickGet() - ulLastTick >= TICK_SECOND/2 )
		{
			// Cambiamos el estado lgico aplicando una operacin XOR
			ulLastTick = xTickGet();
			PORTA ^= 0x10;
			// Aqui termina el cdigo del led parpadeante :O, ahora el botn
			if( PORTAbits.RA0 )
			{
				// Incremetar un contador por cada medio segundo que RA0 esta presionado
				ucCount ++;
				if( ucCount > 10 )	// Despues de 5 segundos ejecutar la escritura en EEPROM
				{
					vUARTPuts( xSerial,"Escribiendo datos a la EEPROM!\r\n");
					for( ucCount = 1; ucCount <= 9; ucCount++)
					{
						vUARTPuts( xSerial, "Escribe: ");
						// La llamada a esta funcin es la que realmente realiza la escritura
						vEEPROMWrite( ucCount, ucCount );
						// Conversin simple de nmero binario a caracter ASCII para poder
						// mostrar el nmero en la terminal (ver valores binarios en tabla ASCII)
						vUARTWrite( xSerial, ( ucCount | 0x30 ) );
						vUARTPuts( xSerial, "\r\n");
					}
					// El byte 0xAA en la posicin 0 indica que ya escribimos datps
					// en la memoria EEPROM del PIC
					vEEPROMWrite( 0xAA, 0x00 );
					ucCount = 0;
				}
			}
			else	// Si el boton se suelta mantenemos ucCount en 0
			{
				ucCount = 0;
			}
		}
	}
}

/**
 Implementacin del vector de interrupcin (nico)
*/
void interrupt isr( void )
{
	// Actualizar el conteo del tiempo
	vTickUpdater();
	// Otras interrupciones
}
