#ifndef EEPROM_H
#define	EEPROM_H

#include "Compiler.h"

/**
 * @brief Writes a single byte to the internal EEPROM
 *
 * Initiates a EEPROM write operation at the provided address. This function will
 * not return untill the write operation is complete.
 *
 * @param xData The data to write to EEPROM memory
 * @param xAddress The EEPROM address to store the data
 */
void vEEPROMWrite( BYTE xData, WORD xAddress );

/**
 * @brief Reads a single byte from the internal EEPROM
 *
 * Initiates a EEPROM read operation and returns the data obtained from the
 * internal EEPROM memory.
 *
 * @param xAddress The address to read data from
 * @return The data byte obtained from EEPROM memory
 */
BYTE xEEPROMRead( WORD xAddress );

/**
 * @brief Writes data to built-in EEPROM memory.
 *
 * This function stores data on the internal microcontroller EEPROM. Data to
 * write is taken from the provided buffer pointer.
 *
 * @param xDestOffset The EEPROM address to begin writing
 * @param pvWriteBuffer The buffer containing the data to write to EEPROM
 * @param xWriteCount The number of bytes to write to EEPROM
 */
void vEEPROMWriteBlock( WORD xDestOffset, void * pvWriteBuffer, WORD xWriteCount );

/**
 * @brief Reads data from the built-in EEPROM memory.
 *
 * This function reads data from the internal microcontroller EEPROM and places
 * the data on the provided buffer.
 *
 * @param xSourceOffset The EEPROM address to begin reading
 * @param pvReadBuffer The buffer to place data that is read from EEPROM
 * @param xReadCount The number of bytes to read from EEPROM
 */
void vEEPROMReadBlock( WORD xSrcOffset, void * pvReadBuffer, WORD xReadCount );

#endif


